
# Type: deprecated


Description of why and when this element will no longer be used

URI: [meta:deprecated](https://w3id.org/biolink/biolinkml/meta/deprecated)


## Domain and Range

[Element](Element.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
